@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from typing import Tuple, Union, Iterable
+from typing import Tuple, Union
 import numpy as np
 from numpy.testing import assert_array_equal
 
@@ -180,7 +180,7 @@ class ArrayDescriptor(object):
             the shape provided as a number, a string
             (comma separated for several dimensions) or a tuple/list of strings or ints
         """
-        if isinstance(value, (np.int, np.long)):
+        if isinstance(value, (int, )):
             value = (value, )
         elif isinstance(value, (str, bytes)):
             splitted = value.split(',')
