@@ -4,7 +4,7 @@ Created on Fri Jun 10 21:00:21 2016
 
 @author: MaxBohnet
 """
-
+import sys
 import tempfile
 import numpy as np
 import pytest
@@ -123,7 +123,7 @@ class Test01_ExampleCDefClass:
         example.jobs_j = tuple(range(3))
         np.testing.assert_array_equal(example.jobs_j, np.array([0.0, 1.0, 2.0]))
         #  test setting array with a list of random objects
-        pattern = r"""float\(\) argument must be a string or a number, not .*"""
+        pattern = r"""float\(\) argument must be a string or a (real )?number, not .*"""
         with pytest.raises(TypeError, match=pattern):
             example.jobs_j = [float, type, int]
 
@@ -322,6 +322,9 @@ jobs_j: shape target: \[3\], actual: \(2,\)
             assert np.dtype(dtype.dtype) == data_array.dtype,  'dtype not correct'
         print(example.ds)
 
+    @pytest.mark.xfail(
+        sys.version_info < (3, 7),
+        reason='Somehow in the test configuration the netcdf-backend is not found')
     def test_20_save_and_read_ds(self, example: Example, tempfile_h5: str):
         """Test that saving and re-reading the data works"""
         example.zonenumbers_i = np.array([100, 200, 300])
@@ -383,7 +386,7 @@ jobs_j: shape target: \[3\], actual: \(2,\)
 
         # reset to default (not defined)
         example.reset_array('km_ij')
-        np.testing.assert_array_equal(example.km_ij, np.NAN)
+        np.testing.assert_array_equal(example.km_ij, np.nan)
 
         # reset to default (new value defined)
         example.dtypes['km_ij'].default = 11
@@ -446,9 +449,9 @@ class Test04_Test_Instantiation:
         groups, zones = persons_gi.shape
         example = Example(groups, zones)
 
-        assert example.isnan_py(np.NAN)
-        assert not example.isnan_py(np.NINF)
-        assert not example.isnan_py(np.Inf)
+        assert example.isnan_py(np.nan)
+        assert not example.isnan_py(-np.inf)
+        assert not example.isnan_py(np.inf)
         assert not example.isnan_py(0)
         assert not example.isnan_py(1)
         assert not example.isnan_py(-1)
